/**sequencer is part of JamMo.
License: GPLv2, read more from COPYING

This file is for clutter based gui.
*/
#ifndef _SEQUENCER_H_
#define _SEQUENCER_H_

void start_sequencer();
void init_sequencer();
gboolean sequencer_is_initialized();

#endif /* _SEQUENCER_H_ */

